@@ -1,6 +1,8 @@
 
 using System;
 
+using Mono.Unix;
+
 namespace Tomboy
 {
 	public class Preferences
@@ -11,6 +13,8 @@ namespace Tomboy
 		public const string ENABLE_KEYBINDINGS = "/apps/tomboy/enable_keybindings";
 		public const string ENABLE_STARTUP_NOTES = "/apps/tomboy/enable_startup_notes";
 		public const string ENABLE_AUTO_BULLETED_LISTS = "/apps/tomboy/enable_bulleted_lists";
+		public const string ENABLE_ICON_PASTE = "/apps/tomboy/enable_icon_paste";
+		public const string ENABLE_CLOSE_NOTE_ON_ESCAPE = "/apps/tomboy/enable_close_note_on_escape";
 
 		public const string START_NOTE_URI = "/apps/tomboy/start_note";
 		public const string CUSTOM_FONT_FACE = "/apps/tomboy/custom_font_face";
@@ -34,6 +38,14 @@ namespace Tomboy
 		public const string SYNC_SELECTED_SERVICE_ADDIN = "/apps/tomboy/sync/sync_selected_service_addin";
 		public const string SYNC_CONFIGURED_CONFLICT_BEHAVIOR = "/apps/tomboy/sync/sync_conflict_behavior";
 
+		public const string INSERT_TIMESTAMP_FORMAT = "/apps/tomboy/insert_timestamp/format";
+		
+		// TODO: Convert these into properly localized settings in 0.11.x after freeze is lifted
+		public const string SEARCH_WINDOW_X_POS = "/apps/tomboy/search_window_x_pos";
+		public const string SEARCH_WINDOW_Y_POS = "/apps/tomboy/search_window_y_pos";
+		public const string SEARCH_WINDOW_WIDTH = "/apps/tomboy/search_window_width";
+		public const string SEARCH_WINDOW_HEIGHT = "/apps/tomboy/search_window_height";
+
 		static GConf.Client client;
 		static GConf.NotifyEventHandler changed_handler;
 
@@ -67,6 +79,12 @@ namespace Tomboy
 			case ENABLE_AUTO_BULLETED_LISTS:
 				return true;
 
+			case ENABLE_ICON_PASTE:
+				return false;
+
+			case ENABLE_CLOSE_NOTE_ON_ESCAPE:
+				return true;
+
 			case START_NOTE_URI:
 				return String.Empty;
 
@@ -114,6 +132,9 @@ namespace Tomboy
 
 			case SYNC_CONFIGURED_CONFLICT_BEHAVIOR:
 				return 0;
+
+			case INSERT_TIMESTAMP_FORMAT:
+				return Catalog.GetString ("dddd, MMMM d, h:mm tt");
 			}
 
 			return null;
