@@ -105,8 +105,7 @@ namespace Tomboy
 		static void RegisterPanelAppletFactory ()
 		{
 			// This will block if there is no existing instance running
-			// FIXME: Use custom built panel applet bindings to work around bug in GTK#
-			_Gnome.PanelAppletFactory.Register (typeof (TomboyApplet));
+			Gnome.PanelAppletFactory.Register (typeof (TomboyApplet));
 		}
 
 		static void StartTrayIcon ()
@@ -240,8 +239,14 @@ namespace Tomboy
 
 		static void OnShowHelpAction (object sender, EventArgs args)
 		{
+			Gdk.Screen screen = null;
+			if (tray_icon != null) {
+				Gdk.Rectangle area;
+				Gtk.Orientation orientation;
+				tray_icon.GetGeometry (out screen, out area, out orientation);
+			}
 			GuiUtils.ShowHelp("tomboy.xml", null,
-			                  tray_icon == null ? null : tray_icon.Screen,
+			                  screen,
 			                  null);
 
 		}
